pub struct EvaluationOrder(pub u32);Expand description
Evaluation order assigned to instructions and terminals during numbering. This was previously called InstructionId in the TypeScript compiler.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for EvaluationOrder
impl Clone for EvaluationOrder
Sourcefn clone(&self) -> EvaluationOrder
fn clone(&self) -> EvaluationOrder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EvaluationOrder
Sourceimpl Debug for EvaluationOrder
impl Debug for EvaluationOrder
impl Eq for EvaluationOrder
Sourceimpl Hash for EvaluationOrder
impl Hash for EvaluationOrder
Sourceimpl Ord for EvaluationOrder
impl Ord for EvaluationOrder
Sourcefn cmp(&self, other: &EvaluationOrder) -> Ordering
fn cmp(&self, other: &EvaluationOrder) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EvaluationOrder
impl PartialEq for EvaluationOrder
Sourcefn eq(&self, other: &EvaluationOrder) -> bool
fn eq(&self, other: &EvaluationOrder) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EvaluationOrder
impl PartialOrd for EvaluationOrder
impl StructuralPartialEq for EvaluationOrder