pub struct MutableRange {
pub id: MutableRangeId,
pub start: EvaluationOrder,
pub end: EvaluationOrder,
}Fields
id: MutableRangeIdUnique identity for this logical range. Cloning preserves the ID
(same logical range); use Environment::new_mutable_range() to create
a range with a fresh ID.
start: EvaluationOrderend: EvaluationOrderImplementations
Sourceimpl MutableRange
impl MutableRange
Sourcepub fn contains(&self, eval_order: EvaluationOrder) -> bool
pub fn contains(&self, eval_order: EvaluationOrder) -> bool
Returns true if the given evaluation order falls within this mutable range.
Corresponds to TS inRange({id}, range) / isMutable(instr, place).
Sourcepub fn same_range(&self, other: &MutableRange) -> bool
pub fn same_range(&self, other: &MutableRange) -> bool
Returns true if this range has the same identity as other.
In the TS compiler, this corresponds to checking whether two mutableRange
references point to the same JS object (=== identity).