pub struct ReactiveScope {
pub id: ScopeId,
pub range: MutableRange,
pub dependencies: Vec<ReactiveScopeDependency>,
pub declarations: Vec<(IdentifierId, ReactiveScopeDeclaration)>,
pub reassignments: Vec<IdentifierId>,
pub early_return_value: Option<ReactiveScopeEarlyReturn>,
pub merged: Vec<ScopeId>,
pub loc: Option<SourceLocation>,
}Fields
id: ScopeIdrange: MutableRangedependencies: Vec<ReactiveScopeDependency>The inputs to this reactive scope (populated by later passes)
declarations: Vec<(IdentifierId, ReactiveScopeDeclaration)>The set of values produced by this scope (populated by later passes)
reassignments: Vec<IdentifierId>Identifiers which are reassigned by this scope (populated by later passes)
early_return_value: Option<ReactiveScopeEarlyReturn>If the scope contains an early return, this stores info about it (populated by later passes)
merged: Vec<ScopeId>Scopes that were merged into this one (populated by later passes)
loc: Option<SourceLocation>Source location spanning the scope