ScopeBlockTraversal

Struct ScopeBlockTraversal 

pub struct ScopeBlockTraversal {
    pub block_infos: HashMap<BlockId, ScopeBlockInfo>,
    /* private fields */
}
Helper struct for traversing scope blocks in HIR-form. Equivalent to TS ScopeBlockTraversal class.

Fields

block_infos: HashMap<BlockId, ScopeBlockInfo>

Map from block ID to scope block info

Implementations

Source

impl ScopeBlockTraversal

pub fn new() -> Self

pub fn record_scopes(&mut self, block: &BasicBlock)

Record scope information for a block’s terminal. Equivalent to TS recordScopes.

pub fn is_scope_active(&self, scope_id: ScopeId) -> bool

Returns true if the given scope is currently ‘active’, i.e. if the scope start block but not the scope fallthrough has been recorded.

pub fn current_scope(&self) -> Option<ScopeId>

The current, innermost active scope.