Dominator and post-dominator tree computation.
Port of Dominator.ts and ComputeUnconditionalBlocks.ts. Uses the Cooper/Harvey/Kennedy algorithm from https://www.cs.rice.edu/~keith/Embed/dom.pdf
Structs
- Post
Dominator - Stores the immediate post-dominator for each block.
Functions
- compute_
post_ dominator_ tree - Compute the post-dominator tree for a function.
- compute_
unconditional_ blocks - Compute the set of blocks that are unconditionally executed from the entry.
- post_
dominator_ frontier - Computes the post-dominator frontier of
target_id. These are immediate predecessors of nodes that post-dominatetarget_idfrom which execution may not reachtarget_id. Intuitively, these are the earliest blocks from which execution branches such that it may or may not reach the target block. - post_
dominators_ of - Walks up the post-dominator tree to collect all blocks that post-dominate
target_id.