pub fn compute_unconditional_blocks(
func: &HirFunction,
next_block_id_counter: u32,
) -> Result<HashSet<BlockId>, CompilerDiagnostic>Expand description
Compute the set of blocks that are unconditionally executed from the entry.
Port of ComputeUnconditionalBlocks.ts. Walks the immediate post-dominator chain starting from the function entry. A block is unconditional if it lies on this chain (meaning every path through the function must pass through it).