AliasingEffect

Enum AliasingEffect 

pub enum AliasingEffect {
Show 18 variants Freeze { value: Place, reason: ValueReason, }, Mutate { value: Place, reason: Option<MutationReason>, }, MutateConditionally { value: Place, }, MutateTransitive { value: Place, }, MutateTransitiveConditionally { value: Place, }, Capture { from: Place, into: Place, }, Alias { from: Place, into: Place, }, MaybeAlias { from: Place, into: Place, }, Assign { from: Place, into: Place, }, Create { into: Place, value: ValueKind, reason: ValueReason, }, CreateFrom { from: Place, into: Place, }, ImmutableCapture { from: Place, into: Place, }, Apply { receiver: Place, function: Place, mutates_function: bool, args: Vec<PlaceOrSpreadOrHole>, into: Place, signature: Option<FunctionSignature>, loc: Option<SourceLocation>, }, CreateFunction { captures: Vec<Place>, function_id: FunctionId, into: Place, }, MutateFrozen { place: Place, error: CompilerDiagnostic, }, MutateGlobal { place: Place, error: CompilerDiagnostic, }, Impure { place: Place, error: CompilerDiagnostic, }, Render { place: Place, },
}
Describes the aliasing/mutation/data-flow effects of an instruction or terminal. Ported from TS AliasingEffect in AliasingEffects.ts.

Variants



Freeze

Marks the given value and its direct aliases as frozen.

Fields

value: Place


Mutate

Mutate the value and any direct aliases.

Fields

value: Place


MutateConditionally

Mutate the value conditionally (only if mutable).

Fields

value: Place


MutateTransitive

Mutate the value and transitive captures.

Fields

value: Place


MutateTransitiveConditionally

Mutate the value and transitive captures conditionally.

Fields

value: Place


Capture

Information flow from from to into (non-aliasing capture).

Fields

from: Place
into: Place


Alias

Direct aliasing: mutation of into implies mutation of from.

Fields

from: Place
into: Place


MaybeAlias

Potential aliasing relationship.

Fields

from: Place
into: Place


Assign

Direct assignment: into = from.

Fields

from: Place
into: Place


Create

Creates a value of the given kind at the given place.

Fields

into: Place


CreateFrom

Creates a new value with the same kind as the source.

Fields

from: Place
into: Place


ImmutableCapture

Immutable data flow (escape analysis only, no mutable range influence).

Fields

from: Place
into: Place


Apply

Function call application.

Fields

receiver: Place
function: Place
mutates_function: bool
into: Place


CreateFunction

Function expression creation with captures.

Fields

captures: Vec<Place>
function_id: FunctionId
into: Place


MutateFrozen

Mutation of a value known to be frozen (error).

Fields

place: Place


MutateGlobal

Mutation of a global value (error).

Fields

place: Place


Impure

Side-effect not safe during render.

Fields

place: Place


Render

Value is accessed during render.

Fields

place: Place